@@ -1,4 +1,5 @@
-from typing import Dict, List
+import collections.abc
+from typing import Dict, Iterable, List, Union
 from google.protobuf.descriptor import (
     FieldDescriptor,
     FileDescriptor,
@@ -193,8 +194,12 @@ def get_http_handlers(
 
 
 async def start_gateway(
-    descriptor: FileDescriptor, grpc_port: int, http_port: int = 7070
+    descriptors: Union[FileDescriptor, Iterable[FileDescriptor]],
+    grpc_port: int,
+    http_port: int = 7070,
 ):
+    if not isinstance(descriptors, collections.abc.Iterable):
+        descriptors = [descriptors]
     try:
         logging.info("starting gateway...")
         debug = (
@@ -222,46 +227,47 @@ async def start_gateway(
         channel = insecure_channel(f"localhost:{grpc_port}", options=client_options)
         config = Config()
         config.bind = [f"0.0.0.0:{http_port}"]
-        for service_name in descriptor.services_by_name.keys():
-            service_handler: ServiceDescriptor = descriptor.services_by_name[
-                service_name
-            ]
-            if service_handler.full_name.startswith("grpc."):
-                logging.info(f"skipping service {service_handler.name}")
-            else:
-                logging.info(f"processing service {service_handler.name}")
-                for key in service_handler.methods_by_name.keys():
-                    method_get_handler, request_handler = get_http_handlers(
-                        descriptor, service_handler.name, key, channel
-                    )
-                    service_name = key[1:].split("/")[0].split(".")[-1]
-                    app.add_route(
-                        f"/{service_handler.full_name}.{key}",
-                        route=method_get_handler,
-                        methods=["get"],
-                    )
-                    app.add_route(
-                        f"/{service_handler.full_name}.{key}",
-                        route=request_handler,
-                        methods=["post"],
-                    )
-                    logging.info(f"  processing {key}")
-                    method_descriptor: MethodDescriptor = (
-                        service_handler.methods_by_name[key]
-                    )
-                    method_options: MethodOptions = method_descriptor.GetOptions()
-                    fields: List(FieldDescriptor) = method_options.ListFields()
-                    for field in fields:
-                        if field[0].full_name == "google.api.http":
-                            http_rule: HttpRule = field[1]
-                            for supported_method in supported_methods:
-                                http_path = getattr(http_rule, supported_method)
-                                if http_path != "":
-                                    app.add_route(
-                                        http_path,
-                                        route=request_handler,
-                                        methods=[supported_method],
-                                    )
+        for descriptor in descriptors:
+            for service_name in descriptor.services_by_name:
+                service_handler: ServiceDescriptor = descriptor.services_by_name[
+                    service_name
+                ]
+                if service_handler.full_name.startswith("grpc."):
+                    logging.info(f"skipping service {service_handler.name}")
+                else:
+                    logging.info(f"processing service {service_handler.name}")
+                    for method_name in service_handler.methods_by_name.keys():
+                        method_get_handler, request_handler = get_http_handlers(
+                            descriptor, service_handler.name, method_name, channel
+                        )
+                        service_name = method_name[1:].split("/")[0].split(".")[-1]
+                        app.add_route(
+                            f"/{service_handler.full_name}.{method_name}",
+                            route=method_get_handler,
+                            methods=["get"],
+                        )
+                        app.add_route(
+                            f"/{service_handler.full_name}.{method_name}",
+                            route=request_handler,
+                            methods=["post"],
+                        )
+                        logging.info(f"  processing {method_name}")
+                        method_descriptor: MethodDescriptor = (
+                            service_handler.methods_by_name[method_name]
+                        )
+                        method_options: MethodOptions = method_descriptor.GetOptions()
+                        fields: List[FieldDescriptor] = method_options.ListFields()
+                        for field in fields:
+                            if field[0].full_name == "google.api.http":
+                                http_rule: HttpRule = field[1]
+                                for supported_method in supported_methods:
+                                    http_path = getattr(http_rule, supported_method)
+                                    if http_path != "":
+                                        app.add_route(
+                                            http_path,
+                                            route=request_handler,
+                                            methods=[supported_method],
+                                        )
         logging.info(f"started gateway on port {http_port}")
         return await serve(app, config)
     except Exception as ex:
